From 2d7a865d0221877d78e03f6ce6ea2a0fd2797c7f Mon Sep 17 00:00:00 2001
From: tteck <tteckster@gmail.com>
Date: Thu, 19 Aug 2021 13:31:20 -0400
Subject: [PATCH] Update node-red_container.sh

---
 node-red_container.sh | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/node-red_container.sh b/node-red_container.sh
index a89d5a28..5c614f4a 100644
--- a/node-red_container.sh
+++ b/node-red_container.sh
@@ -101,12 +101,12 @@ info "Using '$STORAGE' for storage location."
 CTID=$(pvesh get /cluster/nextid)
 info "Container ID is $CTID."
 
 # Download latest Debian 10 LXC template
 msg "Updating LXC template list..."
 pveam update >/dev/null
 msg "Downloading LXC template..."
 OSTYPE=debian
-OSVERSION=${OSTYPE}-10
+OSVERSION=${OSTYPE}-11
 mapfile -t TEMPLATES < <(pveam available -section system | sed -n "s/.*\($OSVERSION.*\)/\1/p" | sort -t - -k 2 -V)
 TEMPLATE="${TEMPLATES[-1]}"
 pveam download local $TEMPLATE >/dev/null ||
@@ -101,12 +101,12 @@ info "Using '$STORAGE' for storage location."
 info "Container ID is $CTID."
 
-# Download latest Debian 10 LXC template
+# Download latest Debian 11 LXC template
 msg "Updating LXC template list..."
 pveam update >/dev/null